from pylab import *


def read_librad_radiances(filename):
    """ Read output of libRadtran when radiances are calculated. 
        Works only if one wavelength is calculated.

        Usage:
        (umu, phi, rad_av, rad) = read_librad_radiances(filename)

        Input;
           filename    ascii file including libRadtran output
        Output:
           umu         viewing zenith angles
           phi         viewing azimuth angles
           rad_av      azimutally averaged radiation field
           rad         radiance field, dimensions [Numu, Nphi]
       
    """

    # Find out number of umu and phi
    il=0
    for line in open(filename, 'r'):
        if (il==1):
            fields = line.strip().split()
            Nphi=len(fields)
        il+=1
        
    Numu=il-2
    
    umu=zeros(Numu)
    rad_av=zeros(Numu)
    rad=zeros((Numu,Nphi))
    
    
    il=0
    for line in open(filename, 'r'):
        fields = line.strip().split()
        if (il==0):
            # these data are currently not returned by the function:
            wvl=double(fields[0])
            edir=double(fields[1])
            edn=double(fields[2])
            eup=double(fields[3])
            uavgdir=double(fields[4])
            uavgdn=double(fields[5])
            uavgup=double(fields[6])
        elif (il==1):
            phi=double(fields)
        else:
            umu[il-2]=double(fields[0])
            rad_av[il-2]=double(fields[1])
            rad[il-2,:]=double(fields[2:])
        il+=1
     
    return umu, phi, rad_av, rad

